.. _distances:

Data for Chapter 15
===================

::

   "Atlanta"   "Chicago"   700
   "Atlanta"   "Boston"    1,100
   "Atlanta"   "Chicago"   700
   "Atlanta"   "Dallas"    800
   "Atlanta"   "Denver"    1,450
   "Atlanta"   "Detroit"   750
   "Atlanta"   "Orlando"   400
   "Atlanta"   "Phoenix"   1,850
   "Atlanta"   "Seattle"   2,650
   "Boston"    "Chicago"   1,000
   "Boston"    "Dallas"    1,750
   "Boston"    "Denver"    2,000
   "Boston"    "Detroit"   800
   "Boston"    "Orlando"   1,300
   "Boston"    "Phoenix"   2,650
   "Boston"    "Seattle"   3,000
   "Chicago"   "Dallas"    900
   "Chicago"   "Denver"    1,000
   "Chicago"   "Detroit"   300
   "Chicago"   "Orlando"   1,150
   "Chicago"   "Phoenix"   1,750
   "Chicago"   "Seattle"   2,000
   "Dallas"    "Denver"    800
   "Dallas"    "Detroit"   1,150
   "Dallas"    "Orlando"   1,100
   "Dallas"    "Phoenix"   1,000
   "Dallas"    "Seattle"   2,150
   "Denver"    "Detroit"   1,300
   "Denver"    "Orlando"   1,900
   "Denver"    "Phoenix"   800
   "Denver"    "Seattle"   1,350
   "Detroit"   "Orlando"   1,200
   "Detroit"   "Phoenix"   2,000
   "Detroit"   "Seattle"   2,300
   "Orlando"   "Phoenix"   2,100
   "Orlando"   "Seattle"   3,100
   "Phoenix"   "Seattle"   1,450
